@@ -27,9 +27,7 @@ logger = logging.getLogger("bamboo_engine")
 
 @register_handler(NodeType.ConditionalParallelGateway)
 class ConditionalParallelGatewayHandler(NodeHandler):
-    def execute(
-        self, process_info: ProcessInfo, loop: int, version: str
-    ) -> ExecuteResult:
+    def execute(self, process_info: ProcessInfo, loop: int, version: str) -> ExecuteResult:
         """
         节点的 execute 处理逻辑
 
@@ -58,9 +56,7 @@ class ConditionalParallelGatewayHandler(NodeHandler):
             self.node.id,
             evaluation_refs,
         )
-        additional_refs = self.runtime.get_context_key_references(
-            pipeline_id=top_pipeline_id, keys=evaluation_refs
-        )
+        additional_refs = self.runtime.get_context_key_references(pipeline_id=top_pipeline_id, keys=evaluation_refs)
         evaluation_refs = evaluation_refs.union(additional_refs)
 
         logger.info(
@@ -69,14 +65,9 @@ class ConditionalParallelGatewayHandler(NodeHandler):
             self.node.id,
             evaluation_refs,
         )
-        context_values = self.runtime.get_context_values(
-            pipeline_id=top_pipeline_id, keys=evaluation_refs
-        )
+        context_values = self.runtime.get_context_values(pipeline_id=top_pipeline_id, keys=evaluation_refs)
         context = Context(self.runtime, context_values, root_pipeline_inputs)
-        hydrated_context = {
-            k: transform_escape_char(v)
-            for k, v in context.hydrate(deformat=True).items()
-        }
+        hydrated_context = {k: transform_escape_char(v) for k, v in context.hydrate(deformat=True).items()}
 
         # check conditions
         fork_targets = []
@@ -92,6 +83,7 @@ class ConditionalParallelGatewayHandler(NodeHandler):
             )
             try:
                 result = BoolRule(resolved_evaluate).test()
+                logger.info("[%s] %s %s test result: %s", root_pipeline_id, self.node.id, resolved_evaluate, result)
             except Exception as e:
                 # test failed
                 return self._execute_fail(
@@ -119,9 +111,7 @@ class ConditionalParallelGatewayHandler(NodeHandler):
             from_to=from_to,
         )
 
-        self.runtime.set_state(
-            node_id=self.node.id, to_state=states.FINISHED, set_archive_time=True
-        )
+        self.runtime.set_state(node_id=self.node.id, to_state=states.FINISHED, set_archive_time=True)
 
         return ExecuteResult(
             should_sleep=True,
